@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,10 +18,17 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkdds.endpoint import endpoint_data
+
 class CreateDBInstanceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'CreateDBInstance','dds')
+		RpcRequest.__init__(self, 'Dds', '2015-12-01', 'CreateDBInstance','Dds')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_ResourceOwnerId(self):
 		return self.get_query_params().get('ResourceOwnerId')
@@ -35,12 +42,6 @@ class CreateDBInstanceRequest(RpcRequest):
 	def set_DBInstanceStorage(self,DBInstanceStorage):
 		self.add_query_param('DBInstanceStorage',DBInstanceStorage)
 
-	def get_ClientToken(self):
-		return self.get_query_params().get('ClientToken')
-
-	def set_ClientToken(self,ClientToken):
-		self.add_query_param('ClientToken',ClientToken)
-
 	def get_CouponNo(self):
 		return self.get_query_params().get('CouponNo')
 
@@ -59,18 +60,6 @@ class CreateDBInstanceRequest(RpcRequest):
 	def set_NetworkType(self,NetworkType):
 		self.add_query_param('NetworkType',NetworkType)
 
-	def get_ReplicationFactor(self):
-		return self.get_query_params().get('ReplicationFactor')
-
-	def set_ReplicationFactor(self,ReplicationFactor):
-		self.add_query_param('ReplicationFactor',ReplicationFactor)
-
-	def get_StorageEngine(self):
-		return self.get_query_params().get('StorageEngine')
-
-	def set_StorageEngine(self,StorageEngine):
-		self.add_query_param('StorageEngine',StorageEngine)
-
 	def get_ResourceGroupId(self):
 		return self.get_query_params().get('ResourceGroupId')
 
@@ -83,12 +72,6 @@ class CreateDBInstanceRequest(RpcRequest):
 	def set_SecurityToken(self,SecurityToken):
 		self.add_query_param('SecurityToken',SecurityToken)
 
-	def get_Engine(self):
-		return self.get_query_params().get('Engine')
-
-	def set_Engine(self,Engine):
-		self.add_query_param('Engine',Engine)
-
 	def get_DBInstanceDescription(self):
 		return self.get_query_params().get('DBInstanceDescription')
 
@@ -107,30 +90,6 @@ class CreateDBInstanceRequest(RpcRequest):
 	def set_Period(self,Period):
 		self.add_query_param('Period',Period)
 
-	def get_RestoreTime(self):
-		return self.get_query_params().get('RestoreTime')
-
-	def set_RestoreTime(self,RestoreTime):
-		self.add_query_param('RestoreTime',RestoreTime)
-
-	def get_ResourceOwnerAccount(self):
-		return self.get_query_params().get('ResourceOwnerAccount')
-
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_SrcDBInstanceId(self):
-		return self.get_query_params().get('SrcDBInstanceId')
-
-	def set_SrcDBInstanceId(self,SrcDBInstanceId):
-		self.add_query_param('SrcDBInstanceId',SrcDBInstanceId)
-
-	def get_OwnerAccount(self):
-		return self.get_query_params().get('OwnerAccount')
-
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
 	def get_BackupId(self):
 		return self.get_query_params().get('BackupId')
 
@@ -161,30 +120,90 @@ class CreateDBInstanceRequest(RpcRequest):
 	def set_VSwitchId(self,VSwitchId):
 		self.add_query_param('VSwitchId',VSwitchId)
 
-	def get_AccountPassword(self):
-		return self.get_query_params().get('AccountPassword')
-
-	def set_AccountPassword(self,AccountPassword):
-		self.add_query_param('AccountPassword',AccountPassword)
-
 	def get_AutoRenew(self):
 		return self.get_query_params().get('AutoRenew')
 
 	def set_AutoRenew(self,AutoRenew):
 		self.add_query_param('AutoRenew',AutoRenew)
 
-	def get_VpcId(self):
-		return self.get_query_params().get('VpcId')
-
-	def set_VpcId(self,VpcId):
-		self.add_query_param('VpcId',VpcId)
-
 	def get_ZoneId(self):
 		return self.get_query_params().get('ZoneId')
 
 	def set_ZoneId(self,ZoneId):
 		self.add_query_param('ZoneId',ZoneId)
 
+	def get_ClientToken(self):
+		return self.get_query_params().get('ClientToken')
+
+	def set_ClientToken(self,ClientToken):
+		self.add_query_param('ClientToken',ClientToken)
+
+	def get_ReadonlyReplicas(self):
+		return self.get_query_params().get('ReadonlyReplicas')
+
+	def set_ReadonlyReplicas(self,ReadonlyReplicas):
+		self.add_query_param('ReadonlyReplicas',ReadonlyReplicas)
+
+	def get_ReplicationFactor(self):
+		return self.get_query_params().get('ReplicationFactor')
+
+	def set_ReplicationFactor(self,ReplicationFactor):
+		self.add_query_param('ReplicationFactor',ReplicationFactor)
+
+	def get_StorageEngine(self):
+		return self.get_query_params().get('StorageEngine')
+
+	def set_StorageEngine(self,StorageEngine):
+		self.add_query_param('StorageEngine',StorageEngine)
+
+	def get_DatabaseNames(self):
+		return self.get_query_params().get('DatabaseNames')
+
+	def set_DatabaseNames(self,DatabaseNames):
+		self.add_query_param('DatabaseNames',DatabaseNames)
+
+	def get_Engine(self):
+		return self.get_query_params().get('Engine')
+
+	def set_Engine(self,Engine):
+		self.add_query_param('Engine',Engine)
+
+	def get_RestoreTime(self):
+		return self.get_query_params().get('RestoreTime')
+
+	def set_RestoreTime(self,RestoreTime):
+		self.add_query_param('RestoreTime',RestoreTime)
+
+	def get_ResourceOwnerAccount(self):
+		return self.get_query_params().get('ResourceOwnerAccount')
+
+	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
+		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
+
+	def get_SrcDBInstanceId(self):
+		return self.get_query_params().get('SrcDBInstanceId')
+
+	def set_SrcDBInstanceId(self,SrcDBInstanceId):
+		self.add_query_param('SrcDBInstanceId',SrcDBInstanceId)
+
+	def get_OwnerAccount(self):
+		return self.get_query_params().get('OwnerAccount')
+
+	def set_OwnerAccount(self,OwnerAccount):
+		self.add_query_param('OwnerAccount',OwnerAccount)
+
+	def get_AccountPassword(self):
+		return self.get_query_params().get('AccountPassword')
+
+	def set_AccountPassword(self,AccountPassword):
+		self.add_query_param('AccountPassword',AccountPassword)
+
+	def get_VpcId(self):
+		return self.get_query_params().get('VpcId')
+
+	def set_VpcId(self,VpcId):
+		self.add_query_param('VpcId',VpcId)
+
 	def get_ChargeType(self):
 		return self.get_query_params().get('ChargeType')
 
